@@ -694,9 +694,6 @@ sub gen_auth_query {
     $extra ||= {};
     my $params = $self->gen_auth_params($method, $url, $token, $extra);
     my %all = (%$extra, %$params);
-    my $query = join('&', sort { $a cmp $b } 
-        map(sprintf(q{%s=%s}, encode_param($_), encode_param($all{$_})),
-        keys %all));
     normalize_params({%all});
 }
 
